pub fn parse_command(text: &str) -> Option<ChatCommand>Expand description
Try to parse a message as a runtime command.
Returns None if the message is not a command.
pub fn parse_command(text: &str) -> Option<ChatCommand>Try to parse a message as a runtime command.
Returns None if the message is not a command.