GroupReplyFilter

Struct GroupReplyFilter 

pub struct GroupReplyFilter { /* private fields */ }
Registry of group reply policies keyed by channel name.

Implementations

Source

impl GroupReplyFilter

pub fn new() -> Self

pub fn with_policy( self, channel: impl Into<String>, policy: GroupReplyPolicy, ) -> Self

pub fn set_policy( &mut self, channel: impl Into<String>, policy: GroupReplyPolicy, )

pub fn should_process(&self, msg: &ChannelMessage) -> bool

Check if a message should be processed according to the group reply policy. Returns true if the message should be processed, false if it should be dropped.